@@ -5,6 +5,7 @@ from concurrent.futures import ThreadPoolExecutor, as_completed
 
 import BatchScript.config
 import time
+import signal
 
 class Worker(object):
 
@@ -14,6 +15,8 @@ class Worker(object):
     results = None
     config = BatchScript.config
 
+    p = None
+
     def __init__(self, func, jobs: ThreadQueue, results: ProcessQueue, config=None):
         self.func = func
         self.jobs = jobs
@@ -22,6 +25,11 @@ class Worker(object):
             self.config = config
         self.executor = ThreadPoolExecutor(self.config.MaxThreadPoolSize)
 
+        def shutdown(signalnum, frame):
+            exit(0)
+        for sig in [signal.SIGINT, signal.SIGHUP, signal.SIGTERM]:
+            signal.signal(sig, shutdown)
+
     def start(self):
         while True:
             job_datas = []
@@ -48,4 +56,3 @@ class Worker(object):
                 timedelta = batch_completed - batch_submit
                 speed = job_data_count / timedelta
                 print("run \033[32m{}\033[0m in batch completed in \033[32m{:.2f}\033[0m seconds with \033[32m{}\033[0m job_datas speed \033[32m{:.2f}\033[0m/s".format(self.func.__name__, timedelta, job_data_count, speed))
-
